from datetime import datetime
from sqlalchemy import Column, Integer, String, DateTime, ForeignKey, Float
from sqlalchemy.orm import relationship

from app.db.base_class import Base


class ClassEnrollment(Base):
    id = Column(Integer, primary_key=True, index=True)
    enrollment_date = Column(DateTime, default=datetime.utcnow)
    grade = Column(Float, nullable=True)
    semester = Column(String(20), nullable=False)
    academic_year = Column(String(10), nullable=False)
    
    # Foreign keys
    student_id = Column(Integer, ForeignKey("student.id"), nullable=False)
    course_id = Column(Integer, ForeignKey("course.id"), nullable=False)
    
    # Relationships
    student = relationship("Student", back_populates="enrollments")
    course = relationship("Course", back_populates="enrollments")
    
    def __repr__(self):
        return f"<ClassEnrollment {self.student_id}_{self.course_id}>"