from sqlalchemy import Column, Integer, String, Text, ForeignKey, Boolean
from sqlalchemy.orm import relationship

from app.db.base_class import Base


class Course(Base):
    id = Column(Integer, primary_key=True, index=True)
    course_code = Column(String(20), unique=True, index=True, nullable=False)
    title = Column(String(100), nullable=False)
    description = Column(Text, nullable=True)
    credits = Column(Integer, default=0)
    is_active = Column(Boolean, default=True)
    
    # Foreign keys
    teacher_id = Column(Integer, ForeignKey("teacher.id"), nullable=True)
    
    # Relationships
    teacher = relationship("Teacher", back_populates="courses")
    enrollments = relationship("ClassEnrollment", back_populates="course")
    
    def __repr__(self):
        return f"<Course {self.course_code}>"